@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-2001 by Solar Designer
+ * Copyright (c) 1996-2001,2005 by Solar Designer
  */
 
 /*
@@ -11,7 +11,6 @@
 #define _JOHN_CHARSET_H
 
 #include "params.h"
-#include "common.h"
 #include "loader.h"
 
 /*
@@ -26,35 +25,38 @@
  * Charset file header.
  */
 struct charset_header {
-/* CHARSET_VERSION */
-	char version[4] CC_PACKED;
+/* CHARSET_V* */
+	char version[4];
+
+/* A checksum of the file or equivalent plus some space for future extensions
+ * (only 4 bytes are used currently) */
+	unsigned char check[24];
 
 /* CHARSET_MIN, CHARSET_MAX */
-	unsigned char min, max CC_PACKED;
+	unsigned char min, max;
 
 /* CHARSET_LENGTH */
-	unsigned char length CC_PACKED;
+	unsigned char length;
 
 /* Number of different characters, up to (max - min + 1) */
-	unsigned char count CC_PACKED;
+	unsigned char count;
 
 /* File offsets for each length, 32-bit little endian */
-	unsigned char offsets[CHARSET_LENGTH][4] CC_PACKED;
+	unsigned char offsets[CHARSET_LENGTH][4];
 
 /*
  * Cracking order.
  *
  * This is a list of current {length, fixed position, character count}.
- * There're CHARSET_LENGTH different lengths, and fixed position is up
+ * There are CHARSET_LENGTH different lengths, and fixed position is up
  * to the current length, which means we have exactly (CHARSET_LENGTH *
  * (CHARSET_LENGTH + 1) / 2) different {length, fixed position} pairs;
  * for each such pair we need to try all charsets from 1 character and
  * up to CHARSET_SIZE characters large.
  */
 	unsigned char order
-		[CHARSET_LENGTH * (CHARSET_LENGTH + 1) / 2 * CHARSET_SIZE * 3]
-		CC_PACKED;
-} CC_PACKED;
+		[CHARSET_LENGTH * (CHARSET_LENGTH + 1) / 2 * CHARSET_SIZE * 3];
+};
 
 /*
  * Reads a charset file header.
