@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 #include <string.h>
@@ -18,7 +18,7 @@ char atoi16[0x100];
 
 static int initialized = 0;
 
-void common_init()
+void common_init(void)
 {
 	char *pos;
 
@@ -26,11 +26,11 @@ void common_init()
 
 	memset(atoi64, 0x7F, sizeof(atoi64));
 	for (pos = itoa64; pos <= &itoa64[63]; pos++)
-		atoi64[(ARCH_INDEX)*pos] = pos - itoa64;
+		atoi64[ARCH_INDEX(*pos)] = pos - itoa64;
 
 	memset(atoi16, 0x7F, sizeof(atoi16));
 	for (pos = itoa16; pos <= &itoa16[15]; pos++)
-		atoi16[(ARCH_INDEX)*pos] = pos - itoa16;
+		atoi16[ARCH_INDEX(*pos)] = pos - itoa16;
 
 	atoi16['A'] = atoi16['a'];
 	atoi16['B'] = atoi16['b'];
