@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2000 by Solar Designer
  */
 
 /*
@@ -21,14 +21,15 @@
 #define C_ERROR_TOOCOMPLEX		5
 #define C_ERROR_ARRAYSIZE		6
 #define C_ERROR_DATASIZE		7
-#define C_ERROR_DUPE			8
-#define C_ERROR_RESERVED		9
-#define C_ERROR_NOTINFUNC		10
-#define C_ERROR_NESTEDFUNC		11
-#define C_ERROR_NOTINIF			12
-#define C_ERROR_NOTINLOOP		13
-#define C_ERROR_EOF			14
-#define C_ERROR_INTERNAL		15
+#define C_ERROR_RANGE			8
+#define C_ERROR_DUPE			9
+#define C_ERROR_RESERVED		10
+#define C_ERROR_NOTINFUNC		11
+#define C_ERROR_NESTEDFUNC		12
+#define C_ERROR_NOTINIF			13
+#define C_ERROR_NOTINLOOP		14
+#define C_ERROR_EOF			15
+#define C_ERROR_INTERNAL		16
 
 /*
  * Error names.
@@ -63,7 +64,7 @@ struct c_ident {
  * Runs the compiler, and allocates some memory for its output and the
  * program's data. Returns one of the error codes.
  */
-extern int c_compile(int (*ext_getchar)(), void (*ext_rewind)(),
+extern int c_compile(int (*ext_getchar)(void), void (*ext_rewind)(void),
 	struct c_ident *externs);
 
 /*
