@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 /*
@@ -19,7 +19,7 @@
  * the future. If guesses is not NULL, the cracker will save guessed keys
  * in there (the caller must make sure there's room).
  */
-extern void crk_init(struct db_main *db, void (*fix_state)(),
+extern void crk_init(struct db_main *db, void (*fix_state)(void),
 	struct db_keys *guesses);
 
 /*
@@ -39,12 +39,12 @@ extern int crk_process_salt(struct db_salt *salt);
  * Return current keys range, crk_get_key2() may return NULL if there's only
  * one key. Note: these functions may share a static result buffer.
  */
-extern char *crk_get_key1();
-extern char *crk_get_key2();
+extern char *crk_get_key1(void);
+extern char *crk_get_key2(void);
 
 /*
  * Processes all the buffered keys (unless aborted).
  */
-extern void crk_done();
+extern void crk_done(void);
 
 #endif
