@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-2001 by Solar Designer
+ * Copyright (c) 1996-2001,2004,2006 by Solar Designer
  */
 
 #ifdef __ultrix__
@@ -24,6 +24,7 @@
 #include "cracker.h"
 #include "options.h"
 #include "status.h"
+#include "bench.h"
 
 struct status_main status;
 unsigned int status_restored_time = 0;
@@ -45,30 +46,38 @@ void status_init(int (*get_progress)(void), int start)
 	}
 
 	status_get_progress = get_progress;
+
+	clk_tck_init();
+}
+
+void status_ticks_overflow_safety(void)
+{
+	unsigned int time;
+	clock_t ticks;
+
+	ticks = get_time() - status.start_time;
+	if (ticks > ((clock_t)1 << (sizeof(clock_t) * 8 - 2))) {
+		time = ticks / clk_tck;
+		status_restored_time += time;
+		status.start_time += (clock_t)time * clk_tck;
+	}
 }
 
 void status_update_crypts(unsigned int count)
 {
-	unsigned int saved_hi, time;
-	clock_t ticks;
+	unsigned int saved_hi;
 
 	saved_hi = status.crypts.hi;
 	add32to64(&status.crypts, count);
 
-	if (status.crypts.hi != saved_hi) {
-		ticks = get_time() - status.start_time;
-		if (ticks > ((clock_t)1 << (sizeof(clock_t) * 8 - 2))) {
-			time = ticks / CLK_TCK;
-			status_restored_time += time;
-			status.start_time += (clock_t)time * CLK_TCK;
-		}
-	}
+	if (status.crypts.hi != saved_hi)
+		status_ticks_overflow_safety();
 }
 
 unsigned int status_get_time(void)
 {
 	return status_restored_time +
-		(get_time() - status.start_time) / CLK_TCK;
+		(get_time() - status.start_time) / clk_tck;
 }
 
 static char *status_get_cps(char *buffer)
@@ -76,8 +85,8 @@ static char *status_get_cps(char *buffer)
 	int use_ticks;
 	clock_t ticks;
 	unsigned long time;
-	unsigned int cps_hi, cps_lo;
-	int64 tmp;
+	int64 tmp, cps;
+	unsigned int cps_100;
 
 	use_ticks = !status.crypts.hi && !status_restored_time;
 
@@ -85,19 +94,28 @@ static char *status_get_cps(char *buffer)
 	if (use_ticks)
 		time = ticks;
 	else
-		time = status_restored_time + ticks / CLK_TCK;
+		time = status_restored_time + ticks / clk_tck;
 	if (!time) time = 1;
 
-	tmp = status.crypts;
-	if (use_ticks) mul64by32(&tmp, CLK_TCK);
-	cps_hi = div64by32lo(&tmp, time);
+	cps = status.crypts;
+	if (use_ticks) mul64by32(&cps, clk_tck);
+	div64by32(&cps, time);
 
-	tmp = status.crypts;
-	if (use_ticks) mul64by32(&tmp, CLK_TCK);
-	mul64by32(&tmp, 100);
-	cps_lo = div64by32lo(&tmp, time) % 100;
-
-	sprintf(buffer, cps_hi < 100 ? "%u.%02u" : "%u", cps_hi, cps_lo);
+	if (cps.hi || cps.lo >= 1000000000)
+		sprintf(buffer, "%uM", div64by32lo(&cps, 1000000));
+	else
+	if (cps.lo >= 1000000)
+		sprintf(buffer, "%uK", div64by32lo(&cps, 1000));
+	else
+	if (cps.lo >= 100)
+		sprintf(buffer, "%u", cps.lo);
+	else {
+		tmp = status.crypts;
+		if (use_ticks) mul64by32(&tmp, clk_tck);
+		mul64by32(&tmp, 100);
+		cps_100 = div64by32lo(&tmp, time) % 100;
+		sprintf(buffer, "%u.%02u", cps.lo, cps_100);
+	}
 
 	return buffer;
 }
